tonalanalysistools.InversionIndicator
=====================================

.. abjad-lineage:: abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator

.. autoclass:: abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.extent_to_figured_bass_string
      ~abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.name
      ~abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.number
      ~abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.title
      ~abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.__eq__
      ~abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.__ne__
      ~abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.name
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.number
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.title
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.extent_to_figured_bass_string
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.InversionIndicator.InversionIndicator.InversionIndicator.__repr__
   :noindex:
